class SystemPicturesController < ApplicationController
  before_filter :authenticate_user!, :only => [:index, :show]
  before_filter :authenticate_admin!, :only => [:list, :browse, :create, :update, :destroy]

  private
  
  def set_image(prm)
    img = nil
    if (f = prm[:system_picture][:file]).respond_to?(:read)
      if f.size > 1000000
        @system_picture.width = 0
        @system_picture.height = 0
        @system_picture.ext = 'none'
        @system_picture.filesize = 1.megabytes
      else
        img = Magick::Image.from_blob(f.read).shift
        @system_picture.width = img.columns
        @system_picture.height = img.rows
        @system_picture.ext = img.format.downcase
        @system_picture.filesize = f.size
      end
    else
      dat = Base64.decode64(prm[:system_picture][:file].to_s.gsub(' ', '+')) #rubyのバグ？+でデコードされるべきキャラがスペースになる
      img = Magick::Image.from_blob(dat).shift
      @system_picture.width = img.columns
      @system_picture.height = img.rows
      @system_picture.ext = img.format.downcase
      @system_picture.filesize = 1000
    end
    img
  end
  
  public
  
  # GET /system_pictures
  # GET /system_pictures.json
  def index
    @system_pictures = SystemPicture.all

    respond_to do |format|
      format.html # index.html.erb
      format.json { render json: @system_pictures }
    end
  end

  # GET /system_pictures/1
  # GET /system_pictures/1.json
  def show
    @system_picture = SystemPicture.find(params[:id])

    respond_to do |format|
      opt = {:type => @system_picture.mime_type, :disposition=>"inline"}
      format.png { send_data(@system_picture.restore, opt ) }
      format.gif { send_data(@system_picture.restore, opt ) }
      format.jpeg { send_data(@system_picture.restore, opt ) }
      format.html # show.html.erb
      format.json { render json: @system_picture}
    end
  end

  def list
    @system_pictures = SystemPicture.all

    respond_to do |format|
      format.html { render layout: 'system' }
      format.json { render json: @system_pictures }
    end
  end

  def browse
    @system_picture = SystemPicture.find(params[:id])

    respond_to do |format|
      format.html { render layout: 'system' }
      format.json { render json: @system_picture}
    end
  end


  # POST /system_pictures
  # POST /system_pictures.json
  def create
    @system_picture = SystemPicture.new
    img = set_image params

    respond_to do |format|
      SystemPicture.transaction do
        if @system_picture.save
          if @system_picture.store(img)
            format.html { redirect_to @system_picture, notice: 'system picture was successfully created.' }
            format.json { render json: @system_picture, status: :created, location: @system_picture }
          else
            format.html { redirect_to @system_picture, notice: 'Failed! system picture was NOT created.' }
            format.json { render json: @system_picture.errors, status: :unprocessable_entity }
          end
        else
          format.html { render action: "new" }
          format.json { render json: @system_picture.errors, status: :unprocessable_entity }
        end
      end
    end
  end

  # PUT /system_pictures/1
  # PUT /system_pictures/1.json
  def update
    @system_picture = SystemPicture.find(params[:id])
    img = set_image params

    respond_to do |format|
      SystemPicture.transaction do
        if @system_picture.save
          if @system_picture.store(img)
            format.html { redirect_to @system_picture, notice: 'System picture was successfully updated.' }
            format.json { head :ok }
          else
            format.html { redirect_to @system_picture, notice: 'Failed! System picture was NOT created.' }
            format.json { render json: @system_picture.errors, status: :unprocessable_entity }
          end
        else
          format.html { render action: "edit" }
          format.json { render json: @system_picture.errors, status: :unprocessable_entity }
        end
      end
    end
  end

  # DELETE /system_pictures/1
  # DELETE /system_pictures/1.json
  def destroy
    @system_picture = SystemPicture.find(params[:id])
    SystemPicture.transaction do
      @system_picture.destroy
      
    end
    
    respond_to do |format|
      format.html { redirect_to system_pictures_url }
      format.json { head :ok }
    end
  end
end
